@@ -103,8 +103,7 @@ class ConnectionPool:
         """
         Return a connection to the pool.
         """
-        loop = self.in_use[conn]
-        del self.in_use[conn]
+        loop = self.in_use.pop(conn, None)
         if loop is not None:
             conns, _ = self._ensure_loop(loop)
             conns.append(conn)
@@ -114,7 +113,7 @@ class ConnectionPool:
         Handle a connection that produced an error.
         """
         await self._close_conn(conn)
-        del self.in_use[conn]
+        self.in_use.pop(conn, None)
 
     def reset(self):
         """
@@ -143,10 +142,10 @@ class ConnectionPool:
                 await self._close_conn(conn)
             del self.conn_map[loop]
 
-        for k, v in self.in_use.items():
+        for k, v in tuple(self.in_use.items()):
             if v is loop:
                 await self._close_conn(k)
-                self.in_use[k] = None
+                self.in_use.pop(k, None)
 
     async def close(self):
         """
@@ -199,10 +198,6 @@ class ChannelLock:
             del self.wait_counts[channel]
 
 
-class UnsupportedRedis(Exception):
-    pass
-
-
 class BoundedQueue(asyncio.Queue):
     def put_nowait(self, item):
         if self.full():
@@ -740,41 +735,6 @@ class RedisChannelLayer(BaseChannelLayer):
                         group,
                     )
 
-    def _map_channel_to_connection(self, channel_names, message):
-        """
-        For a list of channel names, bucket each one to a dict keyed by the
-        connection index
-        Also for each channel create a message specific to that channel, adding
-        the __asgi_channel__ key to the message
-        We also return a mapping from channel names to their corresponding Redis
-        keys, and a mapping of channels to their capacity
-        """
-        connection_to_channels = collections.defaultdict(list)
-        channel_to_message = dict()
-        channel_to_capacity = dict()
-        channel_to_key = dict()
-
-        for channel in channel_names:
-            channel_non_local_name = channel
-            if "!" in channel:
-                message = dict(message.items())
-                message["__asgi_channel__"] = channel
-                channel_non_local_name = self.non_local_name(channel)
-            channel_key = self.prefix + channel_non_local_name
-            idx = self.consistent_hash(channel_non_local_name)
-            connection_to_channels[idx].append(channel_key)
-            channel_to_capacity[channel] = self.get_capacity(channel)
-            channel_to_message[channel] = self.serialize(message)
-            # We build a
-            channel_to_key[channel] = channel_key
-
-        return (
-            connection_to_channels,
-            channel_to_message,
-            channel_to_capacity,
-            channel_to_key,
-        )
-
     def _map_channel_keys_to_connection(self, channel_names, message):
         """
         For a list of channel names, GET
